diff --git a/deploy_gitlab_ci.py b/deploy_gitlab_ci.py
index e46d601c63af8356a1cf3ef2b9e7786fb713ae1b..5d7d8ba03f0be19ebc7f209dafbeb36e0f95011a 100755
--- a/deploy_gitlab_ci.py
+++ b/deploy_gitlab_ci.py
@@ -64,7 +64,7 @@ def main():
     project = common.get_project(gitlab, args.project)
 
     # Update submodule
-    integration_branch, _, submodule_project = update_submodule(
+    integration_branch, integration_commit, submodule_project = update_submodule(
         project, args.submodule, args.revision, args.branch
     )
 
@@ -91,12 +91,13 @@ def main():
     else:
         print("Existing integration merge request:\n%s" % mr.web_url)
 
-    # Explicitly trigger a pipeline on the integration branch (automatic pipelines are
-    # disabled for integration merge requests)
-    try:
-        project.pipelines.create({"ref": integration_branch})
-    except GitlabCreateError as e:
-        sys.exit("ERROR: could not create merge request pipeline: %s" % e)
+    # Explicitly trigger a pipeline on the integration branch if it has not run for the
+    # head commit yet (automatic pipelines are disabled for integration branches)
+    if not project.pipelines.list(sha=integration_commit):
+        try:
+            project.pipelines.create({"ref": integration_branch})
+        except GitlabCreateError as e:
+            sys.exit("ERROR: could not create merge request pipeline: %s" % e)
 
     if not args.merge:
         print(